==> haskell-x509-1.7.7-138-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x509.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 x509
version:              1.7.7
visibility:           public
id:                   x509-1.7.7-5nccTIJDr5T2TUMukaplI2
key:                  x509-1.7.7-5nccTIJDr5T2TUMukaplI2
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             X509 reader and writer
description:          X509 reader and writer. please see README
category:             Data
abi:                  4485579845a17b9ff36e3d8627f671b9
exposed:              True
exposed-modules:      Data.X509 Data.X509.EC
hidden-modules:
    Data.X509.Internal Data.X509.CertificateChain
    Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
    Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
    Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
    Data.X509.Signed

import-dirs:          /usr/lib/ghc-9.4.8/site-local/x509-1.7.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/x509-1.7.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/x509-1.7.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-x509
hs-libraries:         HSx509-1.7.7-5nccTIJDr5T2TUMukaplI2
depends:
    asn1-encoding-0.9.6-LAQF2mdo90XHiOLrFlJgSD
    asn1-parse-0.9.5-3bdjCwBKYYJ9oKsDWmUgk3
    asn1-types-0.3.4-AAHBJ3Q1iHABi87v34hXeC base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-A9phujEDgScDbkOFDSuHZa
    hourglass-0.2.12-FqPKt4JKPPsCGLvrQOMMcM
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    pem-0.2.4-AYM9EWcobvrII4LGn0vOpN transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-x509/html/x509.haddock
haddock-html:         /usr/share/doc/haskell-x509/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-1.7.7-139-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x509.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 x509
version:              1.7.7
visibility:           public
id:                   x509-1.7.7-3CIu7QJURfUBxoodgHAC7Y
key:                  x509-1.7.7-3CIu7QJURfUBxoodgHAC7Y
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             X509 reader and writer
description:          X509 reader and writer. please see README
category:             Data
abi:                  4cea0f482523390d17de0be1aff6fde9
exposed:              True
exposed-modules:      Data.X509 Data.X509.EC
hidden-modules:
    Data.X509.Internal Data.X509.CertificateChain
    Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
    Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
    Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
    Data.X509.Signed

import-dirs:          /usr/lib/ghc-9.4.8/site-local/x509-1.7.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/x509-1.7.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/x509-1.7.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-x509
hs-libraries:         HSx509-1.7.7-3CIu7QJURfUBxoodgHAC7Y
depends:
    asn1-encoding-0.9.6-6qnbPIhPHof3Aoo10UHXmC
    asn1-parse-0.9.5-G5jjfwOc0U6218LSFh4YrW
    asn1-types-0.3.4-D7h7QoL5kdUIjKC32aUPvH base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-7SH0LMdXNni1YIZSpAN6jO
    hourglass-0.2.12-6C7WncKLpCRAPwokugQc5U
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    pem-0.2.4-L7fJzdTRuGlB1dYvxJ8LcO transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-x509/html/x509.haddock
haddock-html:         /usr/share/doc/haskell-x509/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
